@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+import importlib.util
 import os
 import re
 import signal
@@ -26,8 +27,11 @@ seen = []
 
 
 def get_view_path():
-    file = os.path.dirname(os.path.realpath(__file__))
-    return os.path.dirname(os.path.dirname(file))
+    module_path = importlib.util.find_spec("lidarr_youtube_downloader").origin
+    dir = os.path.dirname(module_path)
+    print(module_path)
+    print(dir)
+    return
 
 
 def save_seen():
